package Daje::Generate::Templates;
use Mojo::Base -base;

# encoding utf-8
#
# NAME
# ====
#
#     Daje::Templates - It's templates used for generation of Perl and SQL
#
# SYNOPSIS
# ========
#
# use Daje::Templates;
#
# DESCRIPTION
# ===========
#
# Daje::Templates is just templates
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.comE<gt>
#
# W

our $VERSION = "0.08";



1;
__END__



#################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################

=head1 NAME


    Daje::Templates - It's templates used for generation of Perl and SQL



=head1 SYNOPSIS


use Daje::Templates;



=head1 DESCRIPTION

encoding utf-8


Daje::Templates is just templates



=head1 REQUIRES

L<Mojo::Base> 


=head1 METHODS


=head1 AUTHOR


janeskil1525 E<lt>janeskil1525@gmail.comE<gt>

W


=head1 LICENSE


Copyright (C) janeskil1525.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.



=cut

